==> databricks-feature-lookup-0.1.1.tar.gz: databricks-feature-lookup-0.1.1/README.md <==
The Databricks feature lookup client retrieves features from online stores prior to model inference.

# Documentation

Databricks Feature Store on [AWS](https://docs.databricks.com/applications/machine-learning/feature-store/index.html) | [Azure](https://docs.microsoft.com/en-us/azure/databricks/applications/machine-learning/feature-store/) |  [GCP](https://docs.gcp.databricks.com/applications/machine-learning/feature-store/index.html)

# Known issues

## Known conflicts when installed on Databricks ML Runtimes

This library is for online model serving systems and not intended to work on Databricks ML runtimes. Installing this on Databricks Runtime for ML will conflict with pre-installed Feature Store client modules.

# License

**DB license**

Copyright (2021) Databricks, Inc.

This library (the "Software") may not be used except in connection with the Licensee's use of the Databricks Platform Services
pursuant to an Agreement (defined below) between Licensee (defined below) and Databricks, Inc. ("Databricks"). This Software
shall be deemed part of the Downloadable Services under the Agreement, or if the Agreement does not define Downloadable Services,
Subscription Services, or if neither are defined then the term in such Agreement that refers to the applicable Databricks Platform
Services (as defined below) shall be substituted herein for "Downloadable Services". Licensee's use of the Software must comply at
all times with any restrictions applicable to the Downlodable Services and Subscription Services, generally, and must be used in
accordance with any applicable documentation.

Additionally, and notwithstanding anything in the Agreement to the contrary:
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

If you have not agreed to an Agreement or otherwise do not agree to these terms, you may not use the Software.

This license terminates automatically upon the termination of the Agreement or Licensee's breach of these terms.

Agreement: the agreement between Databricks and Licensee governing the use of the Databricks Platform Services, which shall be, with
respect to Databricks, the Databricks Terms of Service located at www.databricks.com/termsofservice, and with respect to Databricks
Community Edition, the Community Edition Terms of Service located at www.databricks.com/ce-termsofuse, in each case unless Licensee
has entered into a separate written agreement with Databricks governing the use of the applicable Databricks Platform Services.

Databricks Platform Services: the Databricks services or the Databricks Community Edition services, according to where the Software is used.

Licensee: the user of the Software, or, if the Software is being used on behalf of a company, the company.

==> databricks-feature-lookup-0.2.1.tar.gz: databricks-feature-lookup-0.2.1/README.md <==
The Databricks feature lookup client retrieves features from online stores prior to model inference.

# Documentation

Databricks Feature Store on [AWS](https://docs.databricks.com/applications/machine-learning/feature-store/index.html) | [Azure](https://docs.microsoft.com/en-us/azure/databricks/applications/machine-learning/feature-store/) |  [GCP](https://docs.gcp.databricks.com/applications/machine-learning/feature-store/index.html)

For release notes, see
- `AWS <https://docs.databricks.com/release-notes/feature-store/databricks-feature-lookup.html>`
- `Azure <https://docs.microsoft.com/en-us/azure/databricks/release-notes/feature-store/databricks-feature-lookup>`
- `GCP <https://docs.gcp.databricks.com/release-notes/feature-store/databricks-feature-lookup.html>`

# Known issues

## Known conflicts when installed on Databricks ML Runtimes

This library is for online model serving systems and not intended to work on Databricks ML runtimes. Installing this on Databricks Runtime for ML will conflict with pre-installed Feature Store client modules.

# License

**DB license**

Copyright (2021) Databricks, Inc.

This library (the "Software") may not be used except in connection with the Licensee's use of the Databricks Platform Services
pursuant to an Agreement (defined below) between Licensee (defined below) and Databricks, Inc. ("Databricks"). This Software
shall be deemed part of the Downloadable Services under the Agreement, or if the Agreement does not define Downloadable Services,
Subscription Services, or if neither are defined then the term in such Agreement that refers to the applicable Databricks Platform
Services (as defined below) shall be substituted herein for "Downloadable Services". Licensee's use of the Software must comply at
all times with any restrictions applicable to the Downlodable Services and Subscription Services, generally, and must be used in
accordance with any applicable documentation.

Additionally, and notwithstanding anything in the Agreement to the contrary:
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

If you have not agreed to an Agreement or otherwise do not agree to these terms, you may not use the Software.

This license terminates automatically upon the termination of the Agreement or Licensee's breach of these terms.

Agreement: the agreement between Databricks and Licensee governing the use of the Databricks Platform Services, which shall be, with
respect to Databricks, the Databricks Terms of Service located at www.databricks.com/termsofservice, and with respect to Databricks
Community Edition, the Community Edition Terms of Service located at www.databricks.com/ce-termsofuse, in each case unless Licensee
has entered into a separate written agreement with Databricks governing the use of the applicable Databricks Platform Services.

Databricks Platform Services: the Databricks services or the Databricks Community Edition services, according to where the Software is used.

Licensee: the user of the Software, or, if the Software is being used on behalf of a company, the company.
